pub struct RustPackageSnapshotError { /* private fields */ }Expand description
A package snapshot failed while validating the package or walking one primary target.
Implementations
Sourceimpl RustPackageSnapshotError
impl RustPackageSnapshotError
Sourcepub fn target(&self) -> Option<TargetId>
pub fn target(&self) -> Option<TargetId>
The primary target whose closure failed, when source traversal began.
Sourcepub fn into_source(self) -> RustSnapshotError
pub fn into_source(self) -> RustSnapshotError
Consume the package context and return the underlying typed failure.